"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var isLeapYear = exports.isLeapYear = function isLeapYear(year) {
    if (!_typeof(+year) === 'number') {
        throw new Error("年份格式不正确");
    }

    if (+year < 1790) {
        throw new Error("年份不能低于1790年");
    }

    return year % 4 === 0 && year % 100 !== 0 || year % 400 === 0;
};

var weekOfMonth = exports.weekOfMonth = function weekOfMonth(date) {
    if (!date) {
        date = new Date();
    }
    if (!(date instanceof Date)) {
        date = new Date(date);
    }
    return new Date(getFullYear(date), getMonth(date), getDay(date)).getDay();
};

var getMonth = exports.getMonth = function getMonth(date) {
    if (!date) {
        date = new Date();
    }
    if (!(date instanceof Date)) {
        date = new Date(date);
    }
    return date.getMonth();
};

var getFullYear = exports.getFullYear = function getFullYear(date) {
    if (!date) {
        date = new Date();
    }
    if (!(date instanceof Date)) {
        date = new Date(date);
    }
    return date.getFullYear();
};

var parseAntDate = exports.parseAntDate = function parseAntDate(value) {
    if (value) {
        value = new Date(value.replace(/-/g, '/'));
    }
    return value;
};
var getDay = exports.getDay = function getDay(date) {
    if (!date) {
        date = new Date();
    }
    if (!(date instanceof Date)) {
        date = new Date(date);
    }
    return date.getDate();
};
var equalDate = exports.equalDate = function equalDate(date1, date2) {
    var year1 = getFullYear(date1);
    var year2 = getFullYear(date2);
    var month1 = getMonth(date1);
    var month2 = getMonth(date2);
    var day1 = getDay(date1);
    var day2 = getDay(date2);
    return year1 == year2 && month1 == month2 && day1 == day2;
};

var pattern = exports.pattern = function pattern(date, format) {
    if (date === undefined || date === null || !(date instanceof Date)) {
        return date;
    }
    var o = {
        "M+": date.getMonth() + 1,
        "d+": date.getDate(),
        "(H|h)+": date.getHours(),
        "m+": date.getMinutes(),
        "s+": date.getSeconds(),
        "q+": Math.floor((date.getMonth() + 3) / 3),
        "S": date.getMilliseconds()
    };

    if (/(y+)/.test(format)) {
        format = format.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
    }

    for (var k in o) {
        if (new RegExp("(" + k + ")").test(format)) {
            format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
        }
    }
    return format;
};

exports.default = {
    isLeapYear: isLeapYear,
    weekOfMonth: weekOfMonth,
    getMonth: getMonth,
    getFullYear: getFullYear,
    getDay: getDay,
    parseAntDate: parseAntDate,
    equalDate: equalDate,
    pattern: pattern
};