'use strict';

var React = require('react');
var DefaultParams = {};
var DefaultActions = {};
var TreeUtils = require('../../utils/TreeUtils');
var ViewMeta = require('./ViewMeta');
var DataUtil = {};
var RUN_MODE_DESIGN = 'design';
var theme = require('./theme.less');

var _require = require('../../utils/FunctionUtil'),
    deepClone = _require.deepClone;

var JsPluginUtils = require('../../utils/JsPluginUtils');

var _ = require('lodash');

var hasParamPatten = function hasParamPatten(str) {
    var patten = new RegExp('!\{.+}', 'gm');
    return patten.test(str);
};

var authorityButtons = function authorityButtons(appCode, pageCode) {
    return null;
};

var YYCreateView = React.createClass({
    displayName: 'YYCreateView',

    statics: {
        RUN_MODE_DESIGN: RUN_MODE_DESIGN },
    getDefaultProps: function getDefaultProps() {
        return {
            appCode: null,
            pageCode: null,
            billTypeCode: null,
            uiMeta: null,
            uiParser: null,
            uiEvent: null,
            uiParams: null,
            uiRunMode: null };
    },
    getInitialState: function getInitialState() {
        var uiParams = this._processUIParams(this.props.uiParams);
        var uiParser = this._processUIParser(this.props.uiParser);
        var uiEvent = this._processUIEvent(this.props.uiEvent);
        var uiMeta = this._processUIMeta(this.props.uiMeta);
        return {
            uiParams: uiParams, uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent,
            refreshTime: 0 };
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if ('uiParams' in nextProps || 'uiParser' in nextProps || 'uiEvent' in nextProps || 'uiMeta' in nextProps) {
            var uiParams = this._processUIParams(nextProps.uiParams);
            var uiParser = this._processUIParser(nextProps.uiParser);
            var uiEvent = this._processUIEvent(nextProps.uiEvent);
            var uiMeta = this._processUIMeta(nextProps.uiMeta);
            this.setState({
                uiParams: uiParams, uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent,
                refreshTime: this.state.refreshTime + 1
            });
        }
    },
    shouldComponentUpdate: function shouldComponentUpdate(nextProps, nextState) {
        return this.state.refreshTime != nextState.refreshTime;
    },
    componentWillMount: function componentWillMount() {
        var _state = this.state,
            uiMeta = _state.uiMeta,
            uiEvent = _state.uiEvent;

        JsPluginUtils.init({ page: this, uiEvent: uiEvent });
        this._callEvent('onViewWillMount', { uiMeta: uiMeta, uiEvent: uiEvent });
    },
    componentDidMount: function componentDidMount() {
        var _state2 = this.state,
            uiMeta = _state2.uiMeta,
            uiEvent = _state2.uiEvent;

        this._callEvent('onViewDidMount', { uiMeta: uiMeta, uiEvent: uiEvent });
    },
    componentWillUpdate: function componentWillUpdate(nextProps, nextState) {
        var uiMeta = nextState.uiMeta,
            uiEvent = nextState.uiEvent;

        this._callEvent('onViewWillUpdate', { uiMeta: uiMeta, uiEvent: uiEvent });
    },
    componentDidUpdate: function componentDidUpdate(prevProps, prevState) {
        var uiMeta = prevState.uiMeta,
            uiEvent = prevState.uiEvent;

        this._callEvent('onViewDidUpdate', { uiMeta: uiMeta, uiEvent: uiEvent });
    },
    _callEvent: function _callEvent(eventName, _ref) {
        var uiMeta = _ref.uiMeta,
            uiEvent = _ref.uiEvent;

        if (!uiMeta || !uiEvent) return;
        for (var uikey in uiEvent) {
            var itemEvents = uiEvent[uikey];
            if (itemEvents && typeof itemEvents[eventName] == "function") {
                var itemUI = this._findUI({ uiMeta: uiMeta, uikey: uikey });
                if (itemUI) {
                    try {
                        var _itemUI = itemEvents[eventName].call(this, { uiMeta: uiMeta, item: itemUI });
                        if (_itemUI) itemUI = _itemUI;
                    } catch (err) {
                        console.error('[事件回调失败]' + uikey + '.' + eventName, err);
                    }
                }
            }
        }
    },

    _processUIParams: function _processUIParams(uiParams) {
        var _uiParams = Object.assign({}, DefaultParams, uiParams);
        for (var key in _uiParams) {
            var param = _uiParams[key];
            if (param && typeof param == "function") {
                _uiParams[key] = param.call(this);
            }
        }
        return _uiParams;
    },
    _processUIMeta: function _processUIMeta(uiMeta) {
        var _uiMeta = uiMeta;
        return _uiMeta;
    },
    _processUIParser: function _processUIParser(uiParser) {
        var _uiParser = Object.assign({}, this.props.parserControl, uiParser);
        return _uiParser;
    },

    _processUIEvent: function _processUIEvent(uiEvent) {
        var copyDefault = {};
        var copyUiEvent = deepClone(uiEvent);
        var _uiEvent = Object.assign(copyDefault, copyUiEvent);
        for (var uikey in _uiEvent) {
            var itemEvents = _uiEvent[uikey];
            for (var name in itemEvents) {
                try {
                    itemEvents[name] = itemEvents[name].bind(this);
                } catch (err) {
                    console.error('[绑定事件失败]' + uikey + '.' + name + ',检查是否为有效的Function', err);
                }
            }
        }
        return _uiEvent;
    },
    refresh: function refresh(callback, state) {
        this.setState(Object.assign({ refreshTime: this.state.refreshTime + 1 }, state), callback);
    },
    getPage: function getPage() {
        var that = this;
        return that;
    },
    getAppCode: function getAppCode() {
        return this.props.appCode;
    },
    getPageCode: function getPageCode() {
        return this.props.pageCode;
    },

    getJsPluginUrl: function getJsPluginUrl() {
        return this.props.pluginUrl;
    },
    getBillTypeCode: function getBillTypeCode() {
        return this.props.billTypeCode;
    },
    routeTo: function routeTo(url, query, state) {
        if (!this.props.router) {
            console.error('调用routeTo失败,router不存在');return;
        }
        var location = {};
        if (url) location.pathname = url;
        if (query) location.query = query;
        if (state) location.state = state;

        this.props.router.push(location);
    },
    isEmpty: function isEmpty(params) {
        if (!params || params == "") {
            return true;
        }
        return false;
    },
    getRouteParams: function getRouteParams() {
        if (!this.props.location && !this.props.params) {
            console.error('调用getRouteParams失败,location和params均不存在');return;
        }
        return _.isEmpty(this.props.location.state) ? _.isEmpty(this.props.params) ? null : this.props.params : this.props.location.state;
    },
    getRouteQuery: function getRouteQuery() {
        if (!this.props.location) {
            console.error('调用getRouteQuery失败,location不存在');return;
        }
        return _.isEmpty(this.props.location.query) ? null : this.props.location.query;
    },
    goBack: function goBack() {
        if (!this.props.router) {
            console.error('调用goBack失败,router不存在');return;
        }
        this.props.router.goBack();
    },
    goForward: function goForward() {
        if (!this.props.router) {
            console.error('调用goForward失败,router不存在');return;
        }
        this.props.router.goForward();
    },
    goTo: function goTo(to) {
        if (!this.props.router) {
            console.error('调用goTo失败,router不存在');return;
        }
        this.props.router.go(to);
    },
    findUI: function findUI(uikey) {
        if (this.state.uiMeta) {
            var result = this._findUI({ uiMeta: this.state.uiMeta, uikey: uikey });
            if (!result) console.warn('[api.findUI]找不到：' + uikey);
            return result;
        }
        return null;
    },
    _findUI: function _findUI(options) {
        var uiMeta = options.uiMeta,
            uikey = options.uikey;

        var _uiMeta = uiMeta && uiMeta.constructor == Array ? uiMeta : [uiMeta];
        var results = TreeUtils.findWithPropName(_uiMeta, 'uikey', uikey, true, true);
        if (results && results.length > 0) {
            results[0].api = this._findByRef(results[0].nid);
            return results[0];
        }
        return null;
    },
    findUIByType: function findUIByType(uitype) {
        if (this.state.uiMeta) {
            var _uiMeta = this.state.uiMeta && this.state.uiMeta.constructor == Array ? this.state.uiMeta : [this.state.uiMeta];
            var results = TreeUtils.findWithPropName(_uiMeta, 'uitype', uitype, true, false);
            if (results && results.length > 0) {
                var that = this;
                results.forEach(function (item, index) {
                    results[index].api = that._findByRef(item.nid);
                });
                return results;
            }
        }
        return null;
    },
    _findByRef: function _findByRef(ref) {
        return ref && this.refs[ref] ? this.refs[ref] : null;
    },
    findComp: function findComp(uikey) {
        if (this.state.uiMeta) {
            var _uiMeta = this.state.uiMeta && this.state.uiMeta.constructor == Array ? this.state.uiMeta : [this.state.uiMeta];
            var results = TreeUtils.findWithPropName(_uiMeta, 'uikey', uikey, true, true);
            return this._findByRef(results.length > 0 ? results[0].nid : null);
        }
        return null;
    },
    _processParams: function _processParams(node) {
        var uiParams = this.state.uiParams;
        if (this.isEmpty(uiParams)) return;
        if (!node) return;
        var keys = [];

        for (var key in node) {
            var value = node[key];
            if (value && typeof value == "string" && hasParamPatten(value)) {
                keys.push(key);
            };
        }

        if (keys.length == 0) return;
        for (var idx in keys) {
            var propName = keys[idx];
            var propValue = node[propName];
            if (!propValue) break;
            for (var paramKey in uiParams) {
                node[propName] = propValue.replace(new RegExp('!\{' + paramKey + '}', 'gm'), uiParams[paramKey]);
                if (!hasParamPatten(node[propName])) break;
            }
        }
    },
    _getViewContent: function _getViewContent(options) {
        var uiMeta = options.uiMeta,
            uiEvent = options.uiEvent,
            uiParser = options.uiParser;

        var views = null;
        if (uiMeta) {
            if (uiMeta && uiMeta.constructor == Array) {
                views = this._processViews(uiMeta, uiEvent, uiParser);
            } else {
                var offline = uiMeta.offline ? true : false;
                window.offline_flag = offline;
                views = this._processViews([uiMeta], uiEvent, uiParser, offline);
            }
        }
        if (views && views.length > 0) {
            return uiMeta && uiMeta.constructor == Array ? views : views[0];
        } else {
            return null;
        }
    },
    _processViews: function _processViews(items, uiEvent, uiParser, offline, parentType) {
        if (items.constructor && !items.constructor == Array) return null;
        var views = [];
        var _props = this.props,
            uiRunMode = _props.uiRunMode,
            appCode = _props.appCode,
            pageCode = _props.pageCode,
            billTypeCode = _props.billTypeCode;

        var that = this;
        var _props2 = this.props,
            pageCode = _props2.pageCode,
            RunInDesign = _props2.RunInDesign;

        for (var i = 0; i < items.length; i++) {
            var itemUI = items[i];
            if (!itemUI || this.isEmpty(itemUI)) continue;

            var childView = itemUI.children;
            var doEachChild = itemUI.children && itemUI.children.constructor == Array;
            if (doEachChild) {
                childView = this._processViews(itemUI.children, uiEvent, uiParser, offline, itemUI.uitype);
            }

            var itemEvents = null;
            if (itemUI.uikey && uiEvent) {
                itemEvents = uiEvent[itemUI.uikey];
            }

            if (itemUI.uievents) {
                if (!itemEvents) itemEvents = {};

                itemUI.uievents.forEach(function (uiactions, uievent) {
                    itemEvents[uievent] = function (ui, event, actions) {
                        for (var actSeq = 0; actSeq < actions.length; actSeq++) {
                            var action = actions[actSeq];

                            var actionFunc = DefaultActions[action.uiaction];

                            if (typeof actionFunc == 'function') {
                                actionFunc.call(this, { event: event, action: action, ui: ui });
                            }
                        }
                    }.bind(that, itemUI, uievent, uiactions);
                });
            }

            var UIComponent = itemUI.uitype ? uiParser[itemUI.uitype] : null;

            delete itemUI.api;

            var itemProps = Object.assign({
                uiorigin: { appCode: appCode, pageCode: pageCode, billTypeCode: billTypeCode },
                RunInDesign: RunInDesign
            }, itemUI);

            this._processParams(itemProps);

            if (uiRunMode) itemProps.uiRunMode = uiRunMode;

            if (itemUI.uidisabled == true) {
                views.push(itemProps);
            } else if (UIComponent) {
                var privateProps = {};
                if (itemUI.nid) {
                    privateProps.ref = itemUI.nid;
                    if (!itemUI.key) {
                        privateProps.key = pageCode + "_" + itemUI.nid;
                    }
                }
                var itemView = React.createElement(UIComponent, Object.assign({ findUI: this.findUI, offline: offline, parentType: parentType }, itemProps, privateProps, itemEvents), childView);

                var hasAuth = this.isHasAuthorityView(itemUI.uikey);
                if (hasAuth) {
                    views.push(itemView);
                }
            } else {
                var viewMeta = React.createElement(ViewMeta, itemProps);
                views.push(viewMeta);
            }
        }
        return views;
    },
    isHasAuthorityView: function isHasAuthorityView(uikey) {
        return true;
    },
    render: function render() {
        var _state3 = this.state,
            uiMeta = _state3.uiMeta,
            uiParser = _state3.uiParser,
            uiEvent = _state3.uiEvent;

        var viewContent = this._getViewContent({ uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent });
        return viewContent;
    }
});
module.exports = YYCreateView;